==> haskell-unicode-collation-0.1.3.6-12-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-unicode-collation.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 unicode-collation
version:              0.1.3.6
visibility:           public
id:                   unicode-collation-0.1.3.6-FD3DyuY4X59FCCXSNQmMUq
key:                  unicode-collation-0.1.3.6-FD3DyuY4X59FCCXSNQmMUq
license:              BSD-2-Clause
copyright:            2021 John MacFarlane
maintainer:           John MacFarlane <jgm@berkeley.edu>
author:               John MacFarlane
homepage:             https://github.com/jgm/unicode-collation
synopsis:             Haskell implementation of the Unicode Collation Algorithm
description:
    This library provides a pure Haskell implementation of
    the Unicode Collation Algorithm described at
    <http://www.unicode.org/reports/tr10/>.  It is not
    as fully-featured or as performant as @text-icu@, but
    it avoids a dependency on a large C library.
    Locale-specific tailorings are also provided.

category:             Text
abi:                  1f0fe7e5670519a8b2a93f0571f7ed15
exposed:              True
exposed-modules:      Text.Collate Text.Collate.Lang Text.Collate.Normalize
hidden-modules:
    Text.Collate.Trie Text.Collate.Collation Text.Collate.Collator
    Text.Collate.CanonicalCombiningClass Text.Collate.TH
    Text.Collate.Tailorings Text.Collate.UnicodeData

import-dirs:          /usr/lib/ghc-9.2.8/site-local/unicode-collation-0.1.3.6
library-dirs:         /usr/lib/ghc-9.2.8/site-local/unicode-collation-0.1.3.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-unicode-collation
hs-libraries:         HSunicode-collation-0.1.3.6-FD3DyuY4X59FCCXSNQmMUq
depends:
    base-4.16.4.0 binary-0.8.9.0 bytestring-0.11.4.0 containers-0.6.5.1
    parsec-3.1.15.0 template-haskell-2.18.0.0 text-1.2.5.0
    th-lift-instances-0.1.20-IIA6wf2jfwL4V6JOBckTBp

haddock-interfaces:
    /usr/share/doc/haskell-unicode-collation/html/unicode-collation.haddock

haddock-html:         /usr/share/doc/haskell-unicode-collation/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-unicode-collation-0.1.3.6-14-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-unicode-collation.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 unicode-collation
version:              0.1.3.6
visibility:           public
id:                   unicode-collation-0.1.3.6-KkFk90KA8ApFAAscEITKxS
key:                  unicode-collation-0.1.3.6-KkFk90KA8ApFAAscEITKxS
license:              BSD-2-Clause
copyright:            2021 John MacFarlane
maintainer:           John MacFarlane <jgm@berkeley.edu>
author:               John MacFarlane
homepage:             https://github.com/jgm/unicode-collation
synopsis:             Haskell implementation of the Unicode Collation Algorithm
description:
    This library provides a pure Haskell implementation of
    the Unicode Collation Algorithm described at
    <http://www.unicode.org/reports/tr10/>.  It is not
    as fully-featured or as performant as @text-icu@, but
    it avoids a dependency on a large C library.
    Locale-specific tailorings are also provided.

category:             Text
abi:                  5e4f42b367f29324df6b4f135a60baaa
exposed:              True
exposed-modules:      Text.Collate Text.Collate.Lang Text.Collate.Normalize
hidden-modules:
    Text.Collate.Trie Text.Collate.Collation Text.Collate.Collator
    Text.Collate.CanonicalCombiningClass Text.Collate.TH
    Text.Collate.Tailorings Text.Collate.UnicodeData

import-dirs:          /usr/lib/ghc-9.2.8/site-local/unicode-collation-0.1.3.6
library-dirs:         /usr/lib/ghc-9.2.8/site-local/unicode-collation-0.1.3.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-unicode-collation
hs-libraries:         HSunicode-collation-0.1.3.6-KkFk90KA8ApFAAscEITKxS
depends:
    base-4.16.4.0 binary-0.8.9.0 bytestring-0.11.4.0 containers-0.6.5.1
    parsec-3.1.15.0 template-haskell-2.18.0.0 text-1.2.5.0
    th-lift-instances-0.1.20-7UUlrTsIDWL3XQkjxcQngm

haddock-interfaces:
    /usr/share/doc/haskell-unicode-collation/html/unicode-collation.haddock

haddock-html:         /usr/share/doc/haskell-unicode-collation/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
